@@ -25,27 +25,52 @@
 import os
 from osgeo import gdal, gdalconst
 from .filesystem import juststem, tempfilename
-from .module_ogr import find_PROJ_LIB, find_GDAL_DATA
+from .module_ogr import SetGDALEnv, RestoreGDALEnv
 
+def reasampling_method(method):
+    """
+    reasampling_method translation form text to gdalconst
+    """
+    method = method.lower()
+    if method == "near":
+        return gdalconst.GRIORA_NearestNeighbour
+    elif method == "bilinear":
+        return gdalconst.GRIORA_Bilinear
+    elif method == "cubic":
+        return gdalconst.GRIORA_Cubic
+    elif method == "cubicspline":
+        return gdalconst.GRIORA_CubicSpline
+    elif method == "lanczos":
+        return gdalconst.GRIORA_Lanczos
+    elif method == "average":
+        return gdalconst.GRIORA_Average
+    elif method == "rms":
+        return gdalconst.GRIORA_RMS
+    elif method == "mode":
+        return gdalconst.GRIORA_Mode
+    elif method == "gauss":
+        return gdalconst.GRIORA_Gauss
+    else:
+        return gdalconst.GRIORA_Bilinear
 
-def gdalwarp(filelist, fileout=None, dstSRS="", cutline="", cropToCutline=False, pixelsize=(0, 0)):
+def gdalwarp(filelist, fileout=None, dstSRS="", cutline="", cropToCutline=False, pixelsize=(0, 0), resampleAlg="near", format="GTiff"):
     """
     gdalwarp
     """
     fileout = fileout if fileout else tempfilename(suffix=".tif")
 
     kwargs = {
-        "format": "GTiff",
+        "format": format,
         "outputType": gdalconst.GDT_Float32,
         "creationOptions": ["BIGTIFF=YES", "TILED=YES", "BLOCKXSIZE=256", "BLOCKYSIZE=256", "COMPRESS=LZW"],
         "dstNodata": -9999,
-        "resampleAlg": gdalconst.GRIORA_Bilinear,
+        "resampleAlg": reasampling_method(resampleAlg),
         "multithread": True
     }
 
-    if pixelsize[0] > 0 and pixelsize[1] > 0:
+    if pixelsize[0] > 0 and pixelsize[1] != 0:
         kwargs["xRes"] = pixelsize[0]
-        kwargs["yRes"] = pixelsize[1]
+        kwargs["yRes"] = abs(pixelsize[1])
 
     if dstSRS:
         kwargs["dstSRS"] = dstSRS
@@ -55,20 +80,8 @@ def gdalwarp(filelist, fileout=None, dstSRS="", cutline="", cropToCutline=False,
         kwargs["cutlineDSName"] = cutline
         kwargs["cutlineLayer"] = juststem(cutline)
 
-    # gdal.Warp depends on PROJ_LIB and GDAL_DATA --------------------------
-    # os.environ["PROJ_LIB"] = ..../site-packages/osgeo/data/proj
-    # patch PROJ_LIB - save it before and restore after gdalwarp
-    PROJ_LIB = os.environ["PROJ_LIB"] if "PROJ_LIB" in os.environ else ""
-    GDAL_DATA = os.environ["GDAL_DATA"] if "GDAL_DATA" in os.environ else ""
-    # print(find_PROJ_LIB())
-    os.environ["PROJ_LIB"] = find_PROJ_LIB()
-    # print(find_GDAL_DATA())
-    os.environ["GDAL_DATA"] = find_GDAL_DATA()
-
+    SetGDALEnv()
     gdal.Warp(fileout, filelist, **kwargs)
-    if PROJ_LIB:
-        os.environ["PROJ_LIB"] = PROJ_LIB
-    if GDAL_DATA:
-        os.environ["GDAL_DATA"] = GDAL_DATA
+    RestoreGDALEnv()
     # ----------------------------------------------------------------------
     return fileout
